"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.depcheckAction = void 0;

var _chalk = require("chalk");

var _depcheck = _interopRequireWildcard(require("depcheck"));

var _actionConfigs = require("../../../configs/actionConfigs");

var _dependencyError = require("../../errors/dependencyError");

var _dependencyWarn = require("../../errors/dependencyWarn");

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

const options = {
  ignorePatterns: ['node_modules', 'build'],
  parsers: {
    '**/*.js': _depcheck.parser.es6,
    '**/*.jsx': _depcheck.parser.jsx,
    '**/*.ts': _depcheck.parser.typescript,
    '**/*.tsx': _depcheck.parser.typescript
  },
  detectors: [_depcheck.detector.requireCallExpression, _depcheck.detector.importDeclaration],
  specials: [_depcheck.special.babel, _depcheck.special.eslint, _depcheck.special.prettier, _depcheck.special.jest, _depcheck.special.husky]
};

const depcheckAction = async ({
  log
}, {
  path,
  ignorePackages = []
}) => {
  log.debug('Create the dependency list');
  const result = await (0, _depcheck.default)(path, { ...options,
    ignoreMatches: [...ignorePackages, ..._actionConfigs.depcheckIgnorePackages]
  });
  const groups = [{
    title: (0, _chalk.red)('The dependencies are not used'),
    dependencies: result.dependencies
  }, {
    title: (0, _chalk.red)('The dev-dependencies are not used'),
    dependencies: result.devDependencies
  }, {
    title: (0, _chalk.red)('The dependencies is missing'),
    dependencies: Object.keys(result.missing)
  }];
  const output = groups.filter(({
    dependencies
  }) => dependencies.length > 0).flatMap(({
    title,
    dependencies
  }) => [`▸ ${title}`, ...dependencies.sort().map(v => `  ∙ ${v}`), '']);

  if (output.length > 0) {
    if (Object.keys(result.missing).length > 0) {
      throw new _dependencyError.DependencyError('Depcheck error', output);
    }

    throw new _dependencyWarn.DependencyWarn('Depcheck warning', output);
  }
};

exports.depcheckAction = depcheckAction;