"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.spinnerBreak = exports.spinnerAction = exports.isSpinning = void 0;

var _tools = require("@kettil/tools");

var _ora = _interopRequireDefault(require("ora"));

var _spinnerWarnError = require("../errors/spinnerWarnError");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const instance = (0, _ora.default)({
  color: 'white',
  spinner: 'dots'
});

const isSpinning = () => instance.isSpinning;

exports.isSpinning = isSpinning;

const start = text => {
  instance.start(text);
};

const stop = (key, text) => {
  if (isSpinning()) {
    instance[key](text);
  }
};

const succeed = p => {
  stop('succeed');
  return p;
};

const fail = error => {
  if (error instanceof _spinnerWarnError.SpinnerWarnError) {
    stop('warn', error.spinnerText);
  } else {
    stop('fail');
  }

  throw error;
};

const spinnerAction = async (action, text) => {
  start(text);
  return action.then(succeed, fail);
};

exports.spinnerAction = spinnerAction;

const spinnerBreak = () => {
  if (isSpinning()) {
    stop('stop');
    return () => instance.start();
  }

  return _tools.noop;
};

exports.spinnerBreak = spinnerBreak;