"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.env = void 0;

const env = (key, defaultValue) => {
  if (key === undefined) {
    return process.env;
  }

  const upperKey = key.toUpperCase();
  const value = process.env[upperKey];

  if (typeof value === 'undefined') {
    if (typeof defaultValue === 'undefined') {
      throw new TypeError(`The ENV variable "${upperKey}" is not defined`);
    }

    return typeof defaultValue === 'function' ? defaultValue() : defaultValue;
  }

  if (typeof defaultValue === 'number') {
    return Number.parseInt(value, 10);
  }

  return value;
};

exports.env = env;